@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -74,6 +74,7 @@ import com.openexchange.data.conversion.ical.ConversionWarning.Code;
 import com.openexchange.data.conversion.ical.ICalEmitter;
 import com.openexchange.data.conversion.ical.ICalSession;
 import com.openexchange.exception.OXException;
+import com.openexchange.exception.OXException.IncorrectString;
 import com.openexchange.exception.OXException.Truncated;
 import com.openexchange.folderstorage.Type;
 import com.openexchange.folderstorage.type.PrivateType;
@@ -644,6 +645,20 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
         return hasTrimmed;
     }
 
+    @Override
+    protected boolean replaceIncorrectStrings(IncorrectString incorrectString, String replacement) {
+        boolean hasReplaced = false;
+        if (null != this.appointmentToSave) {
+            hasReplaced |= replaceIncorrectString(incorrectString, appointmentToSave, replacement);
+        }
+        if (null != this.exceptionsToSave && 0 < this.exceptionsToSave.size()) {
+            for (final CalendarDataObject calendarObject : exceptionsToSave) {
+                hasReplaced |= replaceIncorrectString(incorrectString, calendarObject, replacement);
+            }
+        }
+        return hasReplaced;
+    }
+
     /**
      * Tries to handle a {@link WebdavProtocolException} that occured during resource creation automatically.
      *
@@ -721,6 +736,19 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
         return false;
     }
 
+    private static boolean replaceIncorrectString(IncorrectString incorrectString, CalendarDataObject calendarObject, String replacement) {
+        Object value = calendarObject.get(incorrectString.getId());
+        if (null != value && String.class.isInstance(value)) {
+            String stringValue = (String) value;
+            String replacedString = stringValue.replaceAll(incorrectString.getIncorrectString(), replacement);
+            if (false == stringValue.equals(replacedString)) {
+                calendarObject.set(incorrectString.getId(), replacedString);
+                return true;
+            }
+        }
+        return false;
+    }
+
     private static boolean looksLikeMaster(final CalendarDataObject cdo) {
         return cdo.containsRecurrenceType() && CalendarObject.NO_RECURRENCE != cdo.getRecurrenceType();
     }
