@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -84,6 +84,8 @@ import com.openexchange.caldav.query.FilterAnalyzerBuilder;
 import com.openexchange.caldav.reports.FilteringResource;
 import com.openexchange.exception.Category;
 import com.openexchange.exception.OXException;
+import com.openexchange.exception.OXException.IncorrectString;
+import com.openexchange.exception.OXException.ProblematicAttribute;
 import com.openexchange.folderstorage.AbstractFolder;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.UserizedFolder;
@@ -91,6 +93,7 @@ import com.openexchange.folderstorage.type.PrivateType;
 import com.openexchange.folderstorage.type.PublicType;
 import com.openexchange.folderstorage.type.SharedType;
 import com.openexchange.groupware.container.CalendarObject;
+import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.java.Streams;
 import com.openexchange.tools.iterator.SearchIterator;
@@ -427,8 +430,24 @@ public abstract class CalDAVFolderCollection<T extends CalendarObject> extends C
         if (false == this.folder.isDefault() && PrivateType.getInstance().equals(this.folder.getType())) {
             this.folder.setName(displayName);
             try {
-                factory.getFolderService().updateFolder(folder, this.folder.getLastModified(), factory.getSession(), null);
+                factory.getFolderService().updateFolder(folder, this.folder.getLastModifiedUTC(), factory.getSession(), null);
             } catch (OXException e) {
+                if ("FLD-0092".equals(e.getErrorCode())) {
+                    /*
+                     * 'Unsupported character "..." in field "Folder name".
+                     */
+                    ProblematicAttribute[] problematics = e.getProblematics();
+                    if (null != problematics && 0 < problematics.length && null != problematics[0] && IncorrectString.class.isInstance(problematics[0])) {
+                        IncorrectString incorrectString = ((IncorrectString) problematics[0]);
+                        if (FolderObject.FOLDER_NAME == incorrectString.getId()) {
+                            String correctedDisplayName = displayName.replace(incorrectString.getIncorrectString(), "");
+                            if (false == correctedDisplayName.equals(displayName)) {
+                                setDisplayName(correctedDisplayName);
+                                return;
+                            }
+                        }
+                    }
+                }
                 throw protocolException(e);
             }
         } else {
