@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,6 +59,7 @@ import com.openexchange.caldav.Tools;
 import com.openexchange.data.conversion.ical.ConversionError;
 import com.openexchange.exception.Category;
 import com.openexchange.exception.OXException;
+import com.openexchange.exception.OXException.IncorrectString;
 import com.openexchange.exception.OXException.ProblematicAttribute;
 import com.openexchange.exception.OXException.Truncated;
 import com.openexchange.groupware.container.CommonObject;
@@ -131,6 +132,14 @@ public abstract class CommonResource<T extends CommonObject> extends AbstractRes
                 LOG.warn("{}: {} - trimming fields and trying again.", this.getUrl(), e.getMessage());
                 retry = true;
             }
+        } else if (Tools.isIncorrectString(e)) {
+            /*
+             * handle by removing problematic characters
+             */
+            if (replaceIncorrectStrings(e, "")) {
+                LOG.warn("{}: {} - removing problematic characters and trying again.", this.getUrl(), e.getMessage());
+                retry = true;
+            }
         } else if ("APP-0093".equals(e.getErrorCode())) {
             /*
              * 'Moving a recurring appointment to another folder is not supported.'
@@ -177,6 +186,20 @@ public abstract class CommonResource<T extends CommonObject> extends AbstractRes
         return hasTrimmed;
     }
 
+    protected abstract boolean replaceIncorrectStrings(IncorrectString incorrectString, String replacement);
+
+    private boolean replaceIncorrectStrings(OXException e, String replacement) {
+        boolean hasReplaced = false;
+        if (null != e.getProblematics()) {
+            for (ProblematicAttribute problematic : e.getProblematics()) {
+                if (IncorrectString.class.isInstance(problematic)) {
+                    hasReplaced |= this.replaceIncorrectStrings((IncorrectString) problematic, replacement);
+                }
+            }
+        }
+        return hasReplaced;
+    }
+
     protected abstract String getFileExtension();
 
     protected abstract void saveObject() throws OXException;
