@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,6 +64,7 @@ import com.openexchange.data.conversion.ical.ConversionWarning;
 import com.openexchange.data.conversion.ical.ICalEmitter;
 import com.openexchange.data.conversion.ical.ICalSession;
 import com.openexchange.exception.OXException;
+import com.openexchange.exception.OXException.IncorrectString;
 import com.openexchange.exception.OXException.Truncated;
 import com.openexchange.groupware.tasks.Task;
 import com.openexchange.webdav.protocol.WebdavPath;
@@ -184,6 +185,22 @@ public class TaskResource extends CalDAVResource<Task> {
         return false;
     }
 
+    @Override
+    protected boolean replaceIncorrectStrings(IncorrectString incorrectString, String replacement) {
+        if (null != taskToSave) {
+            Object value = taskToSave.get(incorrectString.getId());
+            if (null != value && String.class.isInstance(value)) {
+                String stringValue = (String) value;
+                String replacedString = stringValue.replaceAll(incorrectString.getIncorrectString(), replacement);
+                if (false == stringValue.equals(replacedString)) {
+                    taskToSave.set(incorrectString.getId(), replacedString);
+                    return true;
+                }
+            }
+        }
+        return false;
+    }
+
     private void checkForExplicitRemoves(final Task originalTask, final Task updatedTask) {
         /*
          * reset previously set task fields
