@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,6 +61,8 @@ import com.openexchange.caldav.GroupwareCaldavFactory;
 import com.openexchange.caldav.Tools;
 import com.openexchange.caldav.mixins.SupportedCalendarComponentSet;
 import com.openexchange.exception.OXException;
+import com.openexchange.exception.OXException.IncorrectString;
+import com.openexchange.exception.OXException.ProblematicAttribute;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.folderstorage.database.contentType.CalendarContentType;
@@ -135,6 +137,23 @@ public class UndecidedFolderCollection extends CalDAVFolderCollection<CalendarOb
             newFolder.addPermission(getDefaultPermissions());
             newFolder = OXFolderManager.getInstance(factory.getSession()).createFolder(newFolder, true, System.currentTimeMillis());
         } catch (OXException e) {
+            if ("FLD-0092".equals(e.getErrorCode())) {
+                /*
+                 * 'Unsupported character "..." in field "Folder name".
+                 */
+                ProblematicAttribute[] problematics = e.getProblematics();
+                if (null != problematics && 0 < problematics.length && null != problematics[0] && IncorrectString.class.isInstance(problematics[0])) {
+                    IncorrectString incorrectString = ((IncorrectString) problematics[0]);
+                    if (FolderObject.FOLDER_NAME == incorrectString.getId()) {
+                        String correctedDisplayName = displayName.replace(incorrectString.getIncorrectString(), "");
+                        if (false == correctedDisplayName.equals(displayName)) {
+                            displayName = correctedDisplayName;
+                            create();
+                            return;
+                        }
+                    }
+                }
+            }
             throw protocolException(e, HttpServletResponse.SC_FORBIDDEN);
         }
     }
