@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,6 +59,7 @@ import com.openexchange.carddav.mapping.CardDAVMapper;
 import com.openexchange.exception.Category;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.container.Contact;
+import com.openexchange.groupware.tools.mappings.MappedIncorrectString;
 import com.openexchange.groupware.tools.mappings.MappedTruncation;
 import com.openexchange.groupware.tools.mappings.Mapping;
 import com.openexchange.tools.versit.Versit;
@@ -332,14 +333,22 @@ public class ContactResource extends CardDAVResource {
         	LOG.warn("{}: {} - removing image and trying again.", this.getUrl(), e.getMessage());
         	this.contact.removeImage1();
         	retry = true;
-    	} else if (Tools.isDataTruncation(e)) {
-    		/*
-    		 * handle by trimming truncated fields
-    		 */
-        	if (this.trimTruncatedAttributes(e)) {
-        		LOG.warn("{}: {} - trimming fields and trying again.", this.getUrl(), e.getMessage());
-        		retry = true;
-        	}
+        } else if (Tools.isDataTruncation(e)) {
+            /*
+             * handle by trimming truncated fields
+             */
+            if (this.trimTruncatedAttributes(e)) {
+                LOG.warn("{}: {} - trimming fields and trying again.", this.getUrl(), e.getMessage());
+                retry = true;
+            }
+        } else if (Tools.isIncorrectString(e)) {
+            /*
+             * handle by removing incorrect characters
+             */
+            if (this.replaceIncorrectStrings(e, "")) {
+                LOG.warn("{}: {} - removing incorrect characters and trying again.", this.getUrl(), e.getMessage());
+                retry = true;
+            }
     	} else if (Category.CATEGORY_PERMISSION_DENIED.equals(e.getCategory())) {
     		/*
     		 * handle by overriding sync-token
@@ -361,14 +370,23 @@ public class ContactResource extends CardDAVResource {
     	}
 	}
 
-	private boolean trimTruncatedAttributes(OXException e) {
-		try {
-			return MappedTruncation.truncate(e.getProblematics(), this.contact);
-		} catch (OXException x) {
-			LOG.warn("{}: error trying to handle truncated attributes", getUrl(), x);
-			return false;
-		}
-	}
+    private boolean trimTruncatedAttributes(OXException e) {
+        try {
+            return MappedTruncation.truncate(e.getProblematics(), this.contact);
+        } catch (OXException x) {
+            LOG.warn("{}: error trying to handle truncated attributes", getUrl(), x);
+            return false;
+        }
+    }
+
+    private boolean replaceIncorrectStrings(OXException e, String replacement) {
+        try {
+            return MappedIncorrectString.replace(e.getProblematics(), this.contact, replacement);
+        } catch (OXException x) {
+            LOG.warn("{}: error trying to handle truncated attributes", getUrl(), x);
+            return false;
+        }
+    }
 
     private static boolean isGroup(VersitObject versitObject) {
         com.openexchange.tools.versit.Property property = versitObject.getProperty("X-ADDRESSBOOKSERVER-KIND");
